==> ssp-center-api-0.8.42-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotProposalPriceService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotPreWarnInfoRsp;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotPreWarnPageReq;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotProposalPriceDTO;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotProposalPriceReq;

import java.util.List;

/**
 * 风控回流建议分成价格表
 *
 * @author YWG.MID.P
 * @date 2020-09-28 07:29:05
 */
@AdvancedFeignClient
public interface RemoteSlotProposalPriceService {

    SlotProposalPriceDTO getById(Long id);

    void save(SlotProposalPriceDTO dto);

    void updateById(SlotProposalPriceDTO dto);

    void removeByIds(List<Long> ids);

    /**
     * @Description  根据媒体ID集合查询预警广告位顶部统计信息
     * @Param [appIds]
     * @return cn.com.duiba.tuia.ssp.center.api.dto.SlotPreWarnInfoRsp
     **/
    SlotPreWarnInfoRsp getInfoByAppIds(List<Long> appIds);

    /**
     * @Description  预警广告位数量统计
     * @Param [req]
     * @return java.lang.Integer
     **/
    Integer countPreWarnList(SlotPreWarnPageReq req);

    /**
     * 预警广告位数量统计(排除固价分成)
     * @param req
     * @return
     */
    Integer countPreWarnListFilterFixDivision(SlotPreWarnPageReq req);

    /**
     * @Description  预警广告位数据分页查询
     * @Param [req]
     * @return java.util.List<cn.com.duiba.tuia.ssp.center.api.dto.SlotProposalPriceReq>
     **/
    List<SlotProposalPriceDTO> getPageList(SlotPreWarnPageReq req);

    /**
     * 预警广告位数据分页查询(排除固价分成+预期分成价格、建议分成价格、偏离率字段排序)
     * @param req
     * @return
     */
    List<SlotProposalPriceDTO> getPageListFilterFixDivision(SlotPreWarnPageReq req);
    /**
     * @Description  触发定时任务接口
     * @Date 20:11 2020-10-19
     * @Param []
     * @return void
     **/
    void proposalTask();

    /**
     * @Description  删掉昨日左右数据
     * @Date 18:53 2020-10-20
     * @Param []
     * @return void
     **/
    void deleteByDate();
}

==> ssp-center-api-1.2.09-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotProposalPriceService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotPreWarnInfoRsp;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotPreWarnPageReq;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotProposalPriceDTO;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotProposalPriceMediaShareDTO;

import java.util.List;

/**
 * 风控回流建议分成价格表
 *
 * @author YWG.MID.P
 * @date 2020-09-28 07:29:05
 */
@AdvancedFeignClient
public interface RemoteSlotProposalPriceService {

    SlotProposalPriceDTO getById(Long id);

    void save(SlotProposalPriceDTO dto);

    void updateById(SlotProposalPriceDTO dto);

    void removeByIds(List<Long> ids);

    /**
     * @Description  根据媒体ID集合查询预警广告位顶部统计信息
     * @Param [appIds]
     * @return cn.com.duiba.tuia.ssp.center.api.dto.SlotPreWarnInfoRsp
     **/
    SlotPreWarnInfoRsp getInfoByAppIds(List<Long> appIds);

    /**
     * @Description  预警广告位数量统计
     * @Param [req]
     * @return java.lang.Integer
     **/
    Integer countPreWarnList(SlotPreWarnPageReq req);

    /**
     * 预警广告位数量统计(排除固价分成)
     * @param req
     * @return
     */
    Integer countPreWarnListFilterFixDivision(SlotPreWarnPageReq req);

    /**
     * @Description  预警广告位数据分页查询
     * @Param [req]
     * @return java.util.List<cn.com.duiba.tuia.ssp.center.api.dto.SlotProposalPriceReq>
     **/
    List<SlotProposalPriceDTO> getPageList(SlotPreWarnPageReq req);

    /**
     * 预警广告位数据分页查询(排除固价分成+预期分成价格、建议分成价格、偏离率字段排序)
     * @param req
     * @return
     */
    List<SlotProposalPriceMediaShareDTO> getPageListFilterFixDivision(SlotPreWarnPageReq req);
    /**
     * @Description  触发定时任务接口
     * @Date 20:11 2020-10-19
     * @Param []
     * @return void
     **/
    void proposalTask();

    /**
     * @Description  删掉昨日左右数据
     * @Date 18:53 2020-10-20
     * @Param []
     * @return void
     **/
    void deleteByDate();
}
